@@ -1,6 +1,7 @@
+from __future__ import annotations
+
 from abc import ABC
 from typing import Any
-from typing import Dict
 
 
 class Loader(ABC):
@@ -8,8 +9,8 @@ class Loader(ABC):
 
     def __init__(self) -> None:
         super().__init__()
-        self.loaded_values: Dict[str, str] = {}
+        self.loaded_values: dict[str, str] = {}
 
     def load_values(self, **kwargs: Any) -> bool:
         """Override with loading optionation, store within self.loaded_values"""
-        raise NotImplementedError()  # pragma: no cover
+        raise NotImplementedError()
